@@ -1,5 +1,5 @@
 """Provide the Message class."""
-from typing import TYPE_CHECKING, Any, Dict
+from typing import TYPE_CHECKING, Any, Dict, Optional
 
 from ...const import API_PATH
 from .base import RedditBase
@@ -14,12 +14,7 @@ if TYPE_CHECKING:  # pragma: no cover
 class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
     """A class for private messages.
 
-    **Typical Attributes**
-
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor is this list necessarily complete.
+    .. include:: ../../typical_attributes.rst
 
     =============== ================================================================
     Attribute       Description
@@ -44,7 +39,7 @@ class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
 
     @classmethod
     def parse(cls, data: Dict[str, Any], reddit: "praw.Reddit"):
-        """Return an instance of Message or SubredditMessage from ``data``.
+        """Return an instance of :class:`.Message` or :class:`.SubredditMessage` from ``data``.
 
         :param data: The structured data.
         :param reddit: An instance of :class:`.Reddit`.
@@ -75,9 +70,24 @@ class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
         """Return the class's kind."""
         return self._reddit.config.kinds["message"]
 
+    @property
+    def parent(self) -> Optional["praw.models.Message"]:
+        """Return the parent of the message if it exists."""
+        if not self._parent and self.parent_id:
+            self._parent = self._reddit.inbox.message(self.parent_id.split("_")[1])
+        return self._parent
+
+    @parent.setter
+    def parent(self, value):
+        self._parent = value
+
     def __init__(self, reddit: "praw.Reddit", _data: Dict[str, Any]):
-        """Construct an instance of the Message object."""
+        """Initialize a :class:`.Message` instance."""
         super().__init__(reddit, _data=_data, _fetched=True)
+        self._parent = None
+        for reply in _data.get("replies", []):
+            if reply.parent_id == self.fullname:
+                reply.parent = self
 
     def delete(self):
         """Delete the message.
@@ -100,12 +110,7 @@ class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
 class SubredditMessage(Message):
     """A class for messages to a subreddit.
 
-    **Typical Attributes**
-
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor is this list necessarily complete.
+    .. include:: ../../typical_attributes.rst
 
     =============== =================================================================
     Attribute       Description
@@ -129,9 +134,9 @@ class SubredditMessage(Message):
     """
 
     def mute(self):
-        """Mute the sender of this SubredditMessage.
+        """Mute the sender of this :class:`.SubredditMessage`.
 
-        For example, to mute the sender of the first SubredditMessage in the
+        For example, to mute the sender of the first :class:`.SubredditMessage` in the
         authenticated users' inbox:
 
         .. code-block:: python
@@ -147,9 +152,9 @@ class SubredditMessage(Message):
         self._reddit.post(API_PATH["mute_sender"], data={"id": self.fullname})
 
     def unmute(self):
-        """Unmute the sender of this SubredditMessage.
+        """Unmute the sender of this :class:`.SubredditMessage`.
 
-        For example, to unmute the sender of the first SubredditMessage in the
+        For example, to unmute the sender of the first :class:`.SubredditMessage` in the
         authenticated users' inbox:
 
         .. code-block:: python
