@@ -4,7 +4,7 @@ from warnings import warn
 
 from ...const import API_PATH
 from ...exceptions import ClientException
-from ...util.cache import cachedproperty
+from ...util import _deprecate_args, cachedproperty
 from .base import RedditBase
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -14,17 +14,12 @@ if TYPE_CHECKING:  # pragma: no cover
 class RemovalReason(RedditBase):
     """An individual Removal Reason object.
 
-    **Typical Attributes**
-
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor is this list necessarily complete.
+    .. include:: ../../typical_attributes.rst
 
     =========== ==================================
     Attribute   Description
     =========== ==================================
-    ``id``      The id of the removal reason.
+    ``id``      The ID of the removal reason.
     ``message`` The message of the removal reason.
     ``title``   The title of the removal reason.
     =========== ==================================
@@ -34,12 +29,12 @@ class RemovalReason(RedditBase):
     STR_FIELD = "id"
 
     @staticmethod
-    def _warn_reason_id(reason_id_value: Optional[str], id_value: Optional[str]):
-        """Reason id param is deprecated. Warns if it's used.
+    def _warn_reason_id(*, id_value: Optional[str], reason_id_value: Optional[str]):
+        """Reason ID param is deprecated. Warns if it's used.
 
-        :param reason_id_value: The value passed as parameter ``reason_id``.
         :param id_value: Returns the actual value of parameter ``id`` is parameter
             ``reason_id`` is not used.
+        :param reason_id_value: The value passed as parameter ``reason_id``.
 
         """
         if reason_id_value is not None:
@@ -72,16 +67,16 @@ class RemovalReason(RedditBase):
         reason_id: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
     ):
-        """Construct an instance of the Removal Reason object.
+        """Initialize a :class:`.RemovalReason` instance.
 
         :param reddit: An instance of :class:`.Reddit`.
         :param subreddit: An instance of :class:`.Subreddit`.
-        :param id: The id of the removal reason.
-        :param reason_id: (Deprecated) The original name of the ``id`` parameter. Used
-            for backwards compatibility. This parameter should not be used.
+        :param id: The ID of the removal reason.
+        :param reason_id: The original name of the ``id`` parameter. Used for backwards
+            compatibility. This parameter should not be used.
 
         """
-        id = self._warn_reason_id(reason_id, id)
+        id = self._warn_reason_id(id_value=id, reason_id_value=reason_id)
         if (id, _data).count(None) != 1:
             raise ValueError("Either id or _data needs to be given.")
 
@@ -103,17 +98,18 @@ class RemovalReason(RedditBase):
     def delete(self):
         """Delete a removal reason from this subreddit.
 
-        To delete ``"141vv5c16py7d"`` from the subreddit ``"NAME"`` try:
+        To delete ``"141vv5c16py7d"`` from r/test try:
 
         .. code-block:: python
 
-            reddit.subreddit("NAME").mod.removal_reasons["141vv5c16py7d"].delete()
+            reddit.subreddit("test").mod.removal_reasons["141vv5c16py7d"].delete()
 
         """
         url = API_PATH["removal_reason"].format(subreddit=self.subreddit, id=self.id)
         self._reddit.delete(url)
 
-    def update(self, message: Optional[str] = None, title: Optional[str] = None):
+    @_deprecate_args("message", "title")
+    def update(self, *, message: Optional[str] = None, title: Optional[str] = None):
         """Update the removal reason from this subreddit.
 
         .. note::
@@ -123,12 +119,12 @@ class RemovalReason(RedditBase):
         :param message: The removal reason's new message.
         :param title: The removal reason's new title.
 
-        To update ``"141vv5c16py7d"`` from the subreddit ``"NAME"`` try:
+        To update ``"141vv5c16py7d"`` from r/test try:
 
         .. code-block:: python
 
-            reddit.subreddit("NAME").mod.removal_reasons["141vv5c16py7d"].update(
-                message="New message", title="New title"
+            reddit.subreddit("test").mod.removal_reasons["141vv5c16py7d"].update(
+                title="New title", message="New message"
             )
 
         """
@@ -141,7 +137,7 @@ class RemovalReason(RedditBase):
 
 
 class SubredditRemovalReasons:
-    """Provide a set of functions to a Subreddit's removal reasons."""
+    """Provide a set of functions to a :class:`.Subreddit`'s removal reasons."""
 
     def __getitem__(self, reason_id: Union[str, int, slice]) -> RemovalReason:
         """Return the Removal Reason with the ID/number/slice ``reason_id``.
@@ -151,14 +147,14 @@ class SubredditRemovalReasons:
         .. note::
 
             Removal reasons fetched using a specific rule name are lazily loaded, so you
-            might have to access an attribute to get all of the expected attributes.
+            might have to access an attribute to get all the expected attributes.
 
         This method is to be used to fetch a specific removal reason, like so:
 
         .. code-block:: python
 
             reason_id = "141vv5c16py7d"
-            reason = reddit.subreddit("NAME").mod.removal_reasons[reason_id]
+            reason = reddit.subreddit("test").mod.removal_reasons[reason_id]
             print(reason)
 
         You can also use indices to get a numbered removal reason. Since Python uses
@@ -172,17 +168,17 @@ class SubredditRemovalReasons:
         :raises: :py:class:`IndexError` if a removal reason of a specific number does
             not exist.
 
-        For example, to get the second removal reason of the subreddit ``"NAME"``:
+        For example, to get the second removal reason of r/test:
 
         .. code-block:: python
 
-            reason = reddit.subreddit("NAME").mod.removal_reasons[1]
+            reason = reddit.subreddit("test").mod.removal_reasons[1]
 
         To get the last three removal reasons in a subreddit:
 
         .. code-block:: python
 
-            reasons = reddit.subreddit("NAME").mod.removal_reasons[-3:]
+            reasons = reddit.subreddit("test").mod.removal_reasons[-3:]
             for reason in reasons:
                 print(reason)
 
@@ -192,7 +188,7 @@ class SubredditRemovalReasons:
         return RemovalReason(self._reddit, self.subreddit, reason_id)
 
     def __init__(self, subreddit: "praw.models.Subreddit"):
-        """Create a SubredditRemovalReasons instance.
+        """Initialize a :class:`.SubredditRemovalReasons` instance.
 
         :param subreddit: The subreddit whose removal reasons to work with.
 
@@ -207,7 +203,7 @@ class SubredditRemovalReasons:
 
         .. code-block:: python
 
-            for removal_reason in reddit.subreddit("NAME").mod.removal_reasons:
+            for removal_reason in reddit.subreddit("test").mod.removal_reasons:
                 print(removal_reason)
 
         """
@@ -228,21 +224,22 @@ class SubredditRemovalReasons:
             for id, reason_data in response["data"].items()
         ]
 
-    def add(self, message: str, title: str) -> RemovalReason:
+    @_deprecate_args("message", "title")
+    def add(self, *, message: str, title: str) -> RemovalReason:
         """Add a removal reason to this subreddit.
 
         :param message: The message associated with the removal reason.
-        :param title: The title of the removal reason
+        :param title: The title of the removal reason.
 
-        :returns: The RemovalReason added.
+        :returns: The :class:`.RemovalReason` added.
 
-        The message will be prepended with `Hi u/username,` automatically.
+        The message will be prepended with ``Hi u/username,`` automatically.
 
-        To add ``"Test"`` to the subreddit ``"NAME"`` try:
+        To add ``"Test"`` to r/test try:
 
         .. code-block:: python
 
-            reddit.subreddit("NAME").mod.removal_reasons.add(message="Foobar", title="Test")
+            reddit.subreddit("test").mod.removal_reasons.add(title="Test", message="Foobar")
 
         """
         data = {"message": message, "title": title}
