@@ -2,7 +2,9 @@
 import random
 import time
 from collections import OrderedDict
-from typing import Any, Callable, Generator, List, Optional, Set
+from typing import Any, Callable, Generator, List, Optional, Set, Union
+
+from ..util import _deprecate_args
 
 
 class BoundedSet:
@@ -13,12 +15,12 @@ class BoundedSet:
     """
 
     def __init__(self, max_items: int):
-        """Construct an instance of the BoundedSet."""
+        """Initialize a :class:`.BoundedSet` instance."""
         self.max_items = max_items
         self._set = OrderedDict()
 
     def __contains__(self, item: Any) -> bool:
-        """Test if the BoundedSet contains item."""
+        """Test if the :class:`.BoundedSet` contains item."""
         self._access(item)
         return item in self._set
 
@@ -38,7 +40,7 @@ class ExponentialCounter:
     """A class to provide an exponential counter with jitter."""
 
     def __init__(self, max_counter: int):
-        """Initialize an instance of ExponentialCounter.
+        """Initialize an :class:`.ExponentialCounter` instance.
 
         :param max_counter: The maximum base value.
 
@@ -50,7 +52,7 @@ class ExponentialCounter:
         self._base = 1
         self._max = max_counter
 
-    def counter(self) -> int:
+    def counter(self) -> Union[int, float]:
         """Increment the counter and return the current value with jitter."""
         max_jitter = self._base / 16.0
         value = self._base + random.random() * max_jitter - max_jitter / 2
@@ -62,18 +64,19 @@ class ExponentialCounter:
         self._base = 1
 
 
+@_deprecate_args("permissions", "known_permissions")
 def permissions_string(
-    permissions: Optional[List[str]], known_permissions: Set[str]
+    *, known_permissions: Set[str], permissions: Optional[List[str]]
 ) -> str:
     """Return a comma separated string of permission changes.
 
+    :param known_permissions: A set of strings representing the available permissions.
     :param permissions: A list of strings, or ``None``. These strings can exclusively
         contain ``+`` or ``-`` prefixes, or contain no prefixes at all. When prefixed,
         the resulting string will simply be the joining of these inputs. When not
         prefixed, all permissions are considered to be additions, and all permissions in
         the ``known_permissions`` set that aren't provided are considered to be
         removals. When ``None``, the result is ``"+all"``.
-    :param known_permissions: A set of strings representing the available permissions.
 
     """
     if permissions is None:
@@ -86,30 +89,34 @@ def permissions_string(
     return ",".join(to_set)
 
 
+@_deprecate_args(
+    "function", "pause_after", "skip_existing", "attribute_name", "exclude_before"
+)
 def stream_generator(
-    function: Callable[[Any], Any],
-    pause_after: Optional[int] = None,
-    skip_existing: bool = False,
+    function: Callable,
+    *,
     attribute_name: str = "fullname",
     exclude_before: bool = False,
+    pause_after: Optional[int] = None,
+    skip_existing: bool = False,
     **function_kwargs: Any,
 ) -> Generator[Any, None, None]:
-    """Yield new items from ListingGenerators and ``None`` when paused.
+    """Yield new items from ``function`` as they become available.
 
-    :param function: A callable that returns a ListingGenerator, e.g.
-        ``subreddit.comments`` or ``subreddit.new``.
+    :param function: A callable that returns a :class:`.ListingGenerator`, e.g.,
+        :meth:`.Subreddit.comments` or :meth:`.Subreddit.new`.
+    :param attribute_name: The field to use as an ID (default: ``"fullname"``).
+    :param exclude_before: When ``True`` does not pass ``params`` to ``function``
+        (default: ``False``).
     :param pause_after: An integer representing the number of requests that result in no
         new items before this function yields ``None``, effectively introducing a pause
         into the stream. A negative value yields ``None`` after items from a single
         response have been yielded, regardless of number of new items obtained in that
         response. A value of ``0`` yields ``None`` after every response resulting in no
-        new items, and a value of ``None`` never introduces a pause (default: None).
-    :param skip_existing: When True does not yield any results from the first request
-        thereby skipping any items that existed in the stream prior to starting the
-        stream (default: False).
-    :param attribute_name: The field to use as an id (default: "fullname").
-    :param exclude_before: When True does not pass ``params`` to ``functions`` (default:
-        False).
+        new items, and a value of ``None`` never introduces a pause (default: ``None``).
+    :param skip_existing: When ``True``, this does not yield any results from the first
+        request thereby skipping any items that existed in the stream prior to starting
+        the stream (default: ``False``).
 
     Additional keyword arguments will be passed to ``function``.
 
@@ -117,7 +124,7 @@ def stream_generator(
 
         This function internally uses an exponential delay with jitter between
         subsequent responses that contain no new results, up to a maximum delay of just
-        over a 16 seconds. In practice that means that the time before pause for
+        over 16 seconds. In practice, that means that the time before pause for
         ``pause_after=N+1`` is approximately twice the time before pause for
         ``pause_after=N``.
 
@@ -133,7 +140,7 @@ def stream_generator(
 
     .. code-block:: python
 
-        subreddit = reddit.subreddit("redditdev")
+        subreddit = reddit.subreddit("test")
         for comment in subreddit.stream.comments(pause_after=6):
             if comment is None:
                 break
@@ -143,7 +150,7 @@ def stream_generator(
 
     .. code-block:: python
 
-        subreddit = reddit.subreddit("help")
+        subreddit = reddit.subreddit("test")
         comment_stream = subreddit.stream.comments(pause_after=5)
 
         for comment in comment_stream:
@@ -157,13 +164,13 @@ def stream_generator(
             print(comment)
 
     To bypass the internal exponential backoff, try the following. This approach is
-    useful if you are monitoring a subreddit with infrequent activity, and you want the
-    to consistently learn about new items from the stream as soon as possible, rather
-    than up to a delay of just over sixteen seconds.
+    useful if you are monitoring a subreddit with infrequent activity, and you want to
+    consistently learn about new items from the stream as soon as possible, rather than
+    up to a delay of just over sixteen seconds.
 
     .. code-block:: python
 
-        subreddit = reddit.subreddit("help")
+        subreddit = reddit.subreddit("test")
         for comment in subreddit.stream.comments(pause_after=0):
             if comment is None:
                 continue
